==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver.pm <==
package WebGUI::i18n::Spanish::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => 1226520174,
    'message' => 'Venta realizada. Orden #'
  },
  'credit card' => {
    'lastUpdated' => 1226520187,
    'message' => 'Tarjeta de Cr&eacute;dito'
  },
  'email receipt template' => {
    'lastUpdated' => 1226520208,
    'message' => 'Plantilla para Recibo v&iacute;a Correo Electr&oacute;nico'
  },
  'email receipt template help' => {
    'lastUpdated' => 1226520242,
    'message' => 'Plantilla a utilizar para la construcci&oacute;n de los Recibos enviados al usuario a trav&eacute;s de Correo Electr&oacute;nico.'
  },
  'enabled' => {
    'lastUpdated' => 1226520258,
    'message' => 'Habilitado'
  },
  'enabled help' => {
    'lastUpdated' => 1226521027,
    'message' => 'Establece si el m&eacute;todo de pago est&aacute; habilitado.'
  },
  'error processing payment' => {
    'lastUpdated' => 1226521059,
    'message' => 'Error durante el Procesamiento del Pago'
  },
  'error processing payment message' => {
    'lastUpdated' => 1226521245,
    'message' => 'Ocurri&oacute; un error durante el procesamiento de su pago. Usualmente esto es consecuencia de alg&uacute;n error al suministrar los datos. Tambi&eacute;n existe la posibilidad de que la conectividad hacia el servicio de cobro sea inestable o que Ud. no disponga de fondos suficientes en su cuenta para hacer el pago. El error concreto aparece a continuaci&oacute;n, tal cual fue recibido desde el servicio de cobro. Use el bot&oacute;n &quot;Regresar&quot; de su navegador para retroceder a la p&aacute;gina anterior y corregir los datos si ese fuera el problema. Si el problema persiste, por favor cont&aacute;ctenos.'
  },
  'label' => {
    'lastUpdated' => 1226521273,
    'message' => 'Etiqueta'
  },
  'label help' => {
    'lastUpdated' => 1226521310,
    'message' => 'El nombre con el cual ser&aacute; identificado este Servicio de Cobro en la pantalla M&eacute;todos de Pago.'
  },
  'payment methods' => {
    'lastUpdated' => 1226521338,
    'message' => 'M&eacute;todos de Pago'
  },
  'receipt email template' => {
    'lastUpdated' => 1226521359,
    'message' => 'Plantilla para Recibos por Correo Electr&oacute;nico'
  },
  'receipt email template help' => {
    'lastUpdated' => 1226521421,
    'message' => '&iquest;Cu&aacute;l plantilla debe ser utilizada para generar el mensaje de Correo Electr&oacute;nico conteniendo el Recibo de compra para los usuarios?'
  },
  'receipt subject' => {
    'lastUpdated' => 1226521442,
    'message' => 'Recibo de Compra - Orden #'
  },
  'sale notification group' => {
    'lastUpdated' => 1226521462,
    'message' => 'Grupo a Notificar de la Venta'
  },
  'sale notification group help' => {
    'lastUpdated' => 1226521489,
    'message' => '&iquest;Cu&aacute;l Grupo debe ser notificado cuando ocurra una transacci&oacute;n de venta?'
  },
  'try again' => {
    'lastUpdated' => 1226521509,
    'message' => 'Regrese a la p&aacute;gina anterior e intente de nuevo.'
  },
  'who can use' => {
    'lastUpdated' => 1226521651,
    'message' => 'Grupo de Usuarios'
  },
  'who can use help' => {
    'lastUpdated' => 1226521619,
    'message' => 'Especifica el Grupo que puede utilizar este M&eacute;todo de Pago.'
  }
}
;

1;

==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver.pm <==
package WebGUI::i18n::Spanish::PayDriver;
use utf8;
our $I18N = {
  'a sale has been made' => {
    'lastUpdated' => '1226520174',
    'message' => 'Venta realizada. Orden #'
  },
  'cart summary variables' => {
    'lastUpdated' => '1276813221',
    'message' => 'Variables para Resumen de Carrito'
  },
  'cart summary variables help' => {
    'lastUpdated' => '1276813249',
    'message' => 'Estas variables están disponibles en todas las plantillas para métodos de pago, permitiendo presentar el resumen del carrito de compras al usuario.'
  },
  'credit card' => {
    'lastUpdated' => '1226520187',
    'message' => 'Tarjeta de Cr&eacute;dito'
  },
  'email receipt template' => {
    'lastUpdated' => '1226520208',
    'message' => 'Plantilla para Recibo v&iacute;a Correo Electr&oacute;nico'
  },
  'email receipt template help' => {
    'lastUpdated' => '1226520242',
    'message' => 'Plantilla a utilizar para la construcci&oacute;n de los Recibos enviados al usuario a trav&eacute;s de Correo Electr&oacute;nico.'
  },
  'enabled' => {
    'lastUpdated' => '1226520258',
    'message' => 'Habilitado'
  },
  'enabled help' => {
    'lastUpdated' => '1226521027',
    'message' => 'Establece si el m&eacute;todo de pago est&aacute; habilitado.'
  },
  'error processing payment' => {
    'lastUpdated' => '1226521059',
    'message' => 'Error durante el Procesamiento del Pago'
  },
  'error processing payment message' => {
    'lastUpdated' => '1226521245',
    'message' => 'Ocurri&oacute; un error durante el procesamiento de su pago. Usualmente esto es consecuencia de alg&uacute;n error al suministrar los datos. Tambi&eacute;n existe la posibilidad de que la conectividad hacia el servicio de cobro sea inestable o que Ud. no disponga de fondos suficientes en su cuenta para hacer el pago. El error concreto aparece a continuaci&oacute;n, tal cual fue recibido desde el servicio de cobro. Use el bot&oacute;n &quot;Regresar&quot; de su navegador para retroceder a la p&aacute;gina anterior y corregir los datos si ese fuera el problema. Si el problema persiste, por favor cont&aacute;ctenos.'
  },
  'label' => {
    'lastUpdated' => '1226521273',
    'message' => 'Etiqueta'
  },
  'label help' => {
    'lastUpdated' => '1226521310',
    'message' => 'El nombre con el cual ser&aacute; identificado este Servicio de Cobro en la pantalla M&eacute;todos de Pago.'
  },
  'payment methods' => {
    'lastUpdated' => '1226521338',
    'message' => 'M&eacute;todos de Pago'
  },
  'proceedButton' => {
    'lastUpdated' => '1276813295',
    'message' => 'Un formulario con botón para que el usuario prosiga y envíe sus datos al medo de pago, una vez que ha revisado los cargos.'
  },
  'receipt email template' => {
    'lastUpdated' => '1226521359',
    'message' => 'Plantilla para Recibos por Correo Electr&oacute;nico'
  },
  'receipt email template help' => {
    'lastUpdated' => '1226521421',
    'message' => '&iquest;Cu&aacute;l plantilla debe ser utilizada para generar el mensaje de Correo Electr&oacute;nico conteniendo el Recibo de compra para los usuarios?'
  },
  'receipt subject' => {
    'lastUpdated' => '1226521442',
    'message' => 'Recibo de Compra - Orden #'
  },
  'sale notification group' => {
    'lastUpdated' => '1226521462',
    'message' => 'Grupo a Notificar de la Venta'
  },
  'sale notification group help' => {
    'lastUpdated' => '1226521489',
    'message' => '&iquest;Cu&aacute;l Grupo debe ser notificado cuando ocurra una transacci&oacute;n de venta?'
  },
  'template gone' => {
    'lastUpdated' => '1276813338',
    'message' => 'La plantilla para ingresar credenciales ha sido eliminada. Por favor notifique la falla al administrador del sitio.'
  },
  'try again' => {
    'lastUpdated' => '1226521509',
    'message' => 'Regrese a la p&aacute;gina anterior e intente de nuevo.'
  },
  'who can use' => {
    'lastUpdated' => '1226521651',
    'message' => 'Grupo de Usuarios'
  },
  'who can use help' => {
    'lastUpdated' => '1226521619',
    'message' => 'Especifica el Grupo que puede utilizar este M&eacute;todo de Pago.'
  }
}
;

1;
